Module launch

Module launch 

Launch your app.

Functions

launch
Launch a new window with the default config.
launch_cfg
Launch a new window with a custom config. You can use a builder if you wish.
launch_with_props
Launch a new window with a custom title, width and height and the default config.
launch_with_title
Launch a new window with a custom title and the default config.