Launch your app.
Functions
- launch
- Launch a new window with the default config.
- launch_
cfg - Launch a new window with a custom config. You can use a builder if you wish.
- launch_
with_ props - Launch a new window with a custom title, width and height and the default config.
- launch_
with_ title - Launch a new window with a custom title and the default config.