Module pointer Copy item path Source PointerData Data of a Mouse event. MouseButton Describes a button of a mouse controller. PointerType The type of device that triggered a Pointer event. onglobalpointerup The globalpointerup event fires when the user releases the point anywhere in the app. onpointerdown The pointerdown event fires when the user clicks/starts touching an element. onpointerenter The pointerenter event fires when the user starts hovering/touching an element. onpointerleave The pointerleave event fires when the user stops hovering/touching an element. onpointermove The pointermove event fires when the user moves the cursor or touches over an element.
Unlike onpointerenter , this fires even if the user was already hovering over
the element. onpointerup The pointerup event fires when the user releases their mouse button or stops touching the element.